==> owncloud-9.0.3.tgz: owncloud/apps/files_antivirus/l10n/ca.js <==
OC.L10N.register(
    "files_antivirus",
    {
    "Saved" : "Desat",
    "Clean" : "Neteja",
    "Infected" : "Infectat",
    "Unchecked" : "No comprovat",
    "Scanner exit status" : "Estat de sortida de l'escànner",
    "Scanner output" : "Sortida de l'escànner",
    "Saving..." : "Desant...",
    "<strong>Infected file</strong> has been <strong>found</strong>" : "<strong>Arxiu infectat</strong> ha estat<strong> trobat</strong>",
    "File %s is infected with %s" : "L'arxiu %s està infectat amb %s",
    "It is going to be deleted" : "Serà esborrat",
    "Antivirus" : "Antivirus",
    "Virus detected! Can't upload the file %s" : "S'ha detectat un virus! El fitxer %s no es pot pujar",
    "Malware detected" : "S'ha detectat programari maliciós",
    "Greetings {user}," : "Benvingut {user},",
    "Sorry, but a malware was detected in a file you tried to upload and it had to be deleted." : "S'ha detectar programari maliciós en un fitxer que heu intentat pujar i s'ha hagut d'eliminar.",
    "This email is a notification from {host}. Please, do not reply." : "Aquest correu és uan  notificació de {host}. No el respongueu.",
    "File uploaded: {file}" : "Fitxer pujat: {file}",
    "Antivirus Configuration" : "Configuració de l'antivirus",
    "Mode" : "Mode",
    "Executable" : "Executable",
    "Daemon" : "Dimoni",
    "Daemon (Socket)" : "Dimoni (sòcol)",
    "Socket" : "Sòcol",
    "Clamav Socket." : "Sòcol de Clamav.",
    "Not required in Executable Mode." : "No requerit en mode executable.",
    "Host" : "Equip remot",
    "Address of Antivirus Host." : "Adreça del sevidor d'antivirus.",
    "Port" : "Port",
    "Port number of Antivirus Host." : "Número de port del servidor d'antivirus.",
    "Stream Length" : "Longitud de la cadena",
    "ClamAV StreamMaxLength value in bytes." : "Valor StreamMaxLengh de ClamAV en bytes.",
    "Path to clamscan" : "Camí a clamscan",
    "Path to clamscan executable." : "Camí a l'executable de clamscan.",
    "Not required in Daemon Mode." : "No requerit en mode dimoni.",
    "Extra command line options (comma-separated)" : "Opcions extra de la línia de comandos (separades per comes)",
    "Action for infected files found while scanning" : "Acció per als fitxers infectats trobats durant l'escanneig",
    "Only log" : "Només registra",
    "Delete file" : "Elimina el fitxer",
    "Save" : "Desa",
    "Advanced" : "Avançat",
    "Rules" : "Regles",
    "Clear All" : "Neteja-ho tot",
    "Reset to defaults" : "Restableix als valors per defecte",
    "Match by" : "Coincideix amb",
    "Scanner exit status or signature to search" : "Estat de sortida de l'escànner o signatura a cercar",
    "Description" : "Descripció",
    "Mark as" : "Marca com a",
    "Add a rule" : "Afegeix una regla"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.3.tgz: owncloud/apps/files_antivirus/l10n/ca.js <==
OC.L10N.register(
    "files_antivirus",
    {
    "Saved" : "Desat",
    "Clean" : "Neteja",
    "Infected" : "Infectat",
    "Unchecked" : "No comprovat",
    "Scanner exit status" : "Estat de sortida de l'escànner",
    "Scanner output" : "Sortida de l'escànner",
    "Saving..." : "Desant...",
    "<strong>Infected file</strong> has been <strong>found</strong>" : "<strong>Arxiu infectat</strong> ha estat<strong> trobat</strong>",
    "File %s is infected with %s" : "L'arxiu %s està infectat amb %s",
    "It is going to be deleted" : "Serà esborrat",
    "Antivirus" : "Antivirus",
    "Virus %s is detected in the file. Upload cannot be completed." : "S'ha detectat el virus %s al fitxer. No es pot completar la càrrega.",
    "Virus detected! Can't upload the file %s" : "S'ha detectat un virus! El fitxer %s no es pot pujar",
    "Malware detected" : "S'ha detectat programari maliciós",
    "Greetings {user}," : "Benvingut {user},",
    "Sorry, but a malware was detected in a file you tried to upload and it had to be deleted." : "S'ha detectar programari maliciós en un fitxer que heu intentat pujar i s'ha hagut d'eliminar.",
    "This email is a notification from {host}. Please, do not reply." : "Aquest correu és uan  notificació de {host}. No el respongueu.",
    "File uploaded: {file}" : "Fitxer pujat: {file}",
    "Antivirus Configuration" : "Configuració de l'antivirus",
    "Mode" : "Mode",
    "Executable" : "Executable",
    "Daemon" : "Dimoni",
    "Daemon (Socket)" : "Dimoni (sòcol)",
    "Socket" : "Sòcol",
    "Clamav Socket." : "Sòcol de Clamav.",
    "Not required in Executable Mode." : "No requerit en mode executable.",
    "Host" : "Equip remot",
    "Address of Antivirus Host." : "Adreça del sevidor d'antivirus.",
    "Port" : "Port",
    "Port number of Antivirus Host." : "Número de port del servidor d'antivirus.",
    "Stream Length" : "Longitud de la cadena",
    "ClamAV StreamMaxLength value in bytes." : "Valor StreamMaxLengh de ClamAV en bytes.",
    "Path to clamscan" : "Camí a clamscan",
    "Path to clamscan executable." : "Camí a l'executable de clamscan.",
    "Not required in Daemon Mode." : "No requerit en mode dimoni.",
    "Extra command line options (comma-separated)" : "Opcions extra de la línia de comandos (separades per comes)",
    "Action for infected files found while scanning" : "Acció per als fitxers infectats trobats durant l'escanneig",
    "Only log" : "Només registra",
    "Delete file" : "Elimina el fitxer",
    "Save" : "Desa",
    "Advanced" : "Avançat",
    "Rules" : "Regles",
    "Clear All" : "Neteja-ho tot",
    "Reset to defaults" : "Restableix als valors per defecte",
    "Match by" : "Coincideix amb",
    "Scanner exit status or signature to search" : "Estat de sortida de l'escànner o signatura a cercar",
    "Description" : "Descripció",
    "Mark as" : "Marca com a",
    "Add a rule" : "Afegeix una regla"
},
"nplurals=2; plural=(n != 1);");
